# PublicTestRunModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**test_run_id** | **str** |  | [optional] 
**test_plan_id** | **str, none_type** |  | [optional] 
**test_plan_global_id** | **int** |  | [optional] 
**name** | **str, none_type** |  | [optional] 
**product_name** | **str, none_type** |  | [optional] 
**build** | **str, none_type** |  | [optional] 
**configurations** | [**[ConfigurationModel], none_type**](ConfigurationModel.md) |  | [optional] 
**auto_tests** | [**[AutoTestModel], none_type**](AutoTestModel.md) |  | [optional] 
**test_points** | [**[PublicTestPointModel], none_type**](PublicTestPointModel.md) |  | [optional] 
**status** | **str, none_type** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


